@@ -6,22 +6,22 @@ Standard ESP32 debug header with UART, reset, and boot control
 
 from circuit_synth import *
 
-
 @circuit(name="Debug_Header")
 def debug_header(vcc_3v3, gnd, debug_tx, debug_rx, debug_en, debug_io0):
     """Debug header for programming and debugging"""
-
+    
     # 2x3 debug header
     debug_header = Component(
         symbol="Connector_Generic:Conn_02x03_Odd_Even",
         ref="J",
-        footprint="Connector_IDC:IDC-Header_2x03_P2.54mm_Vertical",
+        footprint="Connector_IDC:IDC-Header_2x03_P2.54mm_Vertical"
     )
-
+    
     # Header connections (standard ESP32 debug layout)
-    debug_header[1] += debug_en  # EN/RST
-    debug_header[2] += vcc_3v3  # 3.3V
-    debug_header[3] += debug_tx  # TX
-    debug_header[4] += gnd  # GND
-    debug_header[5] += debug_rx  # RX
+    debug_header[1] += debug_en   # EN/RST
+    debug_header[2] += vcc_3v3    # 3.3V
+    debug_header[3] += debug_tx   # TX
+    debug_header[4] += gnd        # GND
+    debug_header[5] += debug_rx   # RX  
     debug_header[6] += debug_io0  # IO0/BOOT
+
