@@ -6,37 +6,29 @@ Clean power regulation from USB-C VBUS to regulated 3.3V
 
 from circuit_synth import *
 
-
 @circuit(name="Power_Supply")
 def power_supply(vbus_in, vcc_3v3_out, gnd):
     """5V to 3.3V power regulation subcircuit"""
-
+    
     # 3.3V regulator
     regulator = Component(
-        symbol="Regulator_Linear:AMS1117-3.3",
+        symbol="Regulator_Linear:AMS1117-3.3", 
         ref="U",
-        footprint="Package_TO_SOT_SMD:SOT-223-3_TabPin2",
+        footprint="Package_TO_SOT_SMD:SOT-223-3_TabPin2"
     )
-
+    
     # Input/output capacitors
-    cap_in = Component(
-        symbol="Device:C",
-        ref="C",
-        value="10uF",
-        footprint="Capacitor_SMD:C_0805_2012Metric",
-    )
-    cap_out = Component(
-        symbol="Device:C",
-        ref="C",
-        value="22uF",
-        footprint="Capacitor_SMD:C_0805_2012Metric",
-    )
-
+    cap_in = Component(symbol="Device:C", ref="C", value="10uF", 
+                      footprint="Capacitor_SMD:C_0805_2012Metric")
+    cap_out = Component(symbol="Device:C", ref="C", value="22uF",
+                       footprint="Capacitor_SMD:C_0805_2012Metric")
+    
     # Connections
-    regulator["VI"] += vbus_in  # Input pin for AMS1117
+    regulator["VI"] += vbus_in   # Input pin for AMS1117
     regulator["VO"] += vcc_3v3_out  # Output pin for AMS1117
     regulator["GND"] += gnd
     cap_in[1] += vbus_in
     cap_in[2] += gnd
     cap_out[1] += vcc_3v3_out
     cap_out[2] += gnd
+
