@@ -2,10 +2,7 @@
 IO module for circuit loading and saving
 """
 
-from .json_loader import (
-    load_circuit_from_dict,
-    load_circuit_from_json_file,
-)
+from .json_loader import load_circuit_from_dict, load_circuit_from_json_file
 
 __all__ = [
     "load_circuit_from_json_file",
